/*
 * Copyright (c) 2021-2023 HPMicro
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

#ifndef HPM_BOARD_H
#define HPM_BOARD_H
#include <stdio.h>

/* SDK drivers */
#include "hpm_clock_drv.h"
#include "hpm_common.h"
#include "hpm_gpio_drv.h"
#include "hpm_soc.h"
#include "hpm_soc_feature.h"

/* Debug Console */
#include "hpm_debug_console.h"

/* Board */
#include "pinmux.h"

#define BOARD_CPU_FREQ        (648000000UL)
#define BOARD_CORE_VOLTAGE_MV (1200UL)

#define BOARD_DEBUG_UART_BAUD (115200UL)

#define BOARD_LED_COUNT 3

#define BOARD_LED0_GPIO_CTRL HPM_GPIO0
#define BOARD_LED1_GPIO_CTRL HPM_GPIO0
#define BOARD_LED2_GPIO_CTRL HPM_GPIO0

#define BOARD_LED0_GPIO_INDEX GPIO_DI_GPIOB
#define BOARD_LED1_GPIO_INDEX GPIO_DI_GPIOB
#define BOARD_LED2_GPIO_INDEX GPIO_DI_GPIOB

#define BOARD_LED0_GPIO_PIN 29
#define BOARD_LED1_GPIO_PIN 30
#define BOARD_LED2_GPIO_PIN 31

#define BOARD_LED_GPIO_CTRL  BOARD_LED0_GPIO_CTRL
#define BOARD_LED_GPIO_INDEX BOARD_LED0_GPIO_INDEX
#define BOARD_LED_GPIO_PIN   BOARD_LED0_GPIO_PIN

#define BOARD_SDRAM_BASE (0x40000000U)
#define BOARD_SDRAM_SIZE (32 * SIZE_1MB)

#define BOARD_LCD_RES_H (800U)
#define BOARD_LCD_RES_V (480U)

#define BOARD_LCD_BLK_GPIO_CTRL  HPM_GPIO0
#define BOARD_LCD_BLK_GPIO_INDEX GPIO_DI_GPIOB
#define BOARD_LCD_BLK_GPIO_PIN   23

#if defined(__cplusplus)
extern "C" {
#endif /* __cplusplus */

void board_init(void);
void board_clock_init(void);

void board_debug_console_init(void);

void board_led_init(void);
void board_led_set(uint8_t led_id, bool state);

void board_sdram_init(void);

void board_lcd_init(void);

void board_pmp_init(void);

#if defined(__cplusplus)
}
#endif /* __cplusplus */
#endif /* HPM_BOARD_H */
